@@ -525,6 +525,10 @@ class FASTGenomicsClient:
     def _get_bearer_token(self) -> str:
         """ get a bearer token """
         account = self._get_fastgenomics_account()
+
+        if account.fastgenomics_login_method == "bearer":
+            return account.fastgenomics_passphrase
+
         try:
             headers = {'Content-type': 'application/json',
                        'Accept': 'application/json',
@@ -632,7 +636,7 @@ class FASTGenomicsClient:
         logger.debug(f"Reading account file {filename}'")
         if not path.exists(filename):
             raise Exception(
-                "You are not logged in! Please login using 'fg login'")
+                "You are not logged in! Please login using 'fg-cli login'")
 
         with open(filename, 'r') as f:
             data = f.read()
@@ -646,8 +650,8 @@ class FASTGenomicsClient:
         Parameters:
         -----------
         user         : the FASTGenomics user name
-        passphrase   : if login_method is "pat" the personal access token (pat) else the password of the use
-        login_method : pat | password
+        passphrase   : if login_method is "pat" the personal access token (pat), if login_method is "bearer" the bearer token else the password of the user
+        login_method : pat | password | bearer
         url          : the url of the plattform
         """
         directory = FASTGenomicsClient._get_cli_profile_path()
@@ -656,6 +660,8 @@ class FASTGenomicsClient:
 
         if login_method.lower() == "pat":
             login_method = "pat"
+        elif login_method.lower() == "bearer":
+            login_method = "bearer"
         else:
             login_method = "password"
 
@@ -1364,6 +1370,25 @@ class FASTGenomicsDatasetClient(FASTGenomicsClient):
         }
         return r
 
+    def set_metadata(self, dataset_id: str, metadata: dict):
+        """ set bulk metadata for a dataset """
+        assert dataset_id != "", "You have have to provide a dataset id"
+
+        bearer_token = self._get_bearer_token()
+
+        logging.info(f"setting metadata of dataset {dataset_id}")
+        url = self._get_url(f"webclient/api/datasets/{dataset_id}/metadata")
+
+        request_json = json.dumps(metadata)
+        headers = {
+            'Content-type': 'application/json',
+            'Accept': 'application/json',
+            'Authorization': f"Bearer {bearer_token}",
+            'User-Agent': user_agent
+        }
+        response = self.session.put(url, data=request_json, headers=headers)
+        self._handle_response(response)
+
     def delete_dataset(self, dataset_id: str):
         """ delete a dataset """
         assert dataset_id != "", "You have have to provide a dataset id"
